If you want to write regression test scripts for developing embedded systems,
you found the right place!

For details, have a look in `the documentation <http://dfe.github.io/MONK/>`_.
Changes will be tested and built in
`Travis-CI <https://travis-ci.org/DFE/MONK>`_.
